@@ -3,7 +3,7 @@ BEGIN {
   $Dancer::Config::AUTHORITY = 'cpan:SUKRIA';
 }
 #ABSTRACT:  how to configure Dancer to suit your needs
-$Dancer::Config::VERSION = '1.3130';
+$Dancer::Config::VERSION = '1.3132';
 use strict;
 use warnings;
 use base 'Exporter';
@@ -192,12 +192,13 @@ sub load {
     return 1 unless -f conffile;
 
     # load YAML
-    my ( $result, $error ) = Dancer::ModuleLoader->load('YAML');
-    if ( not $result ) {
-        confess "Configuration file found but could not load YAML: $error";
-    }
+    my $module = $SETTINGS->{engines}{YAML}{module} || 'YAML';
 
-    if (!$_LOADED{conffile()}) {
+    my ( $result, $error ) = Dancer::ModuleLoader->load($module);
+    confess "Configuration file found but could not load $module: $error"
+        unless $result;
+
+    unless ($_LOADED{conffile()}) {
         load_settings_from_yaml(conffile);
         $_LOADED{conffile()}++;
     }
@@ -232,12 +233,11 @@ sub load_settings_from_yaml {
     my $config = eval { YAML::LoadFile($file) }
         or confess "Unable to parse the configuration file: $file: $@";
 
-    # groom the values of $config
-    while( my ($k,$v) = each %$config ) {
-        $config->{$k} = Dancer::Config->normalize_setting($k,$v);
-    }
-
-    $SETTINGS = Hash::Merge::Simple::merge( $SETTINGS, $config );
+    $SETTINGS = Hash::Merge::Simple::merge( $SETTINGS, {
+        map {
+            $_ => Dancer::Config->normalize_setting( $_, $config->{$_} )
+        } keys %$config
+    } );
 
     return scalar keys %$config;
 }
@@ -280,7 +280,7 @@ Dancer::Config - how to configure Dancer to suit your needs
 
 =head1 VERSION
 
-version 1.3130
+version 1.3132
 
 =head1 DESCRIPTION
 
@@ -312,6 +312,14 @@ a reference to a hash:
     my $port   = config->{port};
     my $appdir = config->{appdir};
 
+By default, the module L<YAML> will be used to parse the configuration files.
+If desired, it is possible to use L<YAML::XS> instead by changing the YAML
+engine configuration in the application code:
+
+    config->{engines}{YAML}{module} = 'YAML::XS';
+
+See L<Dancer::Serializer::YAML> for more details.
+
 =head1 SUPPORTED SETTINGS
 
 =head2 Run mode and listening interface/port
