@@ -3,7 +3,7 @@ BEGIN {
   $Dancer::Template::TemplateToolkit::AUTHORITY = 'cpan:SUKRIA';
 }
 #ABSTRACT: Template Toolkit wrapper for Dancer
-$Dancer::Template::TemplateToolkit::VERSION = '1.3130';
+$Dancer::Template::TemplateToolkit::VERSION = '1.3132';
 use strict;
 use warnings;
 use Carp;
@@ -61,6 +61,13 @@ sub init {
             : quotemeta($stop_tag)
         );
     }
+    my @embedded = ();
+    if ($self->config->{embedded_templates}) {
+	Dancer::ModuleLoader->load('Template::Provider::FromDATA')
+	    or croak "The Package Template::Provider::FromDATA must be installed to use embedded_templates";
+
+	@embedded = ( LOAD_TEMPLATES => [Template::Provider::FromDATA->new()] );
+    }
 
     my $tt_config = {
         @anycase,
@@ -69,6 +76,7 @@ sub init {
         @inc_path,
         @start,
         @stop,
+        @embedded,
         %{$self->config},
     };
 
@@ -78,9 +86,7 @@ sub init {
 sub render {
     my ($self, $template, $tokens) = @_;
 
-    if ( ! ref $template ) {
-        -f $template or raise core_template => "'$template' doesn't exist or not a regular file";
-    }
+    $self->view_exists($template) or raise core_template => "'$template' doesn't exist or not a regular file";
 
     my $content = "";
     my $charset = setting('charset') || '';
@@ -89,6 +95,32 @@ sub render {
     return $content;
 }
 
+sub view_exists {
+    my ($self, $view) = @_;
+
+    return 1 if ref $view;
+
+    if ($self->config->{embedded_templates}) {
+	eval {
+	    $_engine->context->template($view);
+	};
+	return ! $@;
+    }
+
+    return -f $view;
+}
+
+sub view {
+    my ($self, $view) = @_;
+
+    if ($self->config->{embedded_templates}) {
+	return $view;
+    }
+    else {
+	$self->SUPER::view($view);
+    }
+}
+
 1;
 
 __END__
@@ -103,7 +135,7 @@ Dancer::Template::TemplateToolkit - Template Toolkit wrapper for Dancer
 
 =head1 VERSION
 
-version 1.3130
+version 1.3132
 
 =head1 DESCRIPTION
 
@@ -193,6 +225,25 @@ Change the configuration of the template to Template Toolkit:
 Done! Everything will work fine out of the box, including variables and META
 variables.
 
+=head1 EMBEDDED TEMPLATES
+
+You can embed your templates in your script file, to get a self-contained dancer
+application in one file (inspired by L<http://advent.perldancer.org/2011/3>).
+
+To enable this:
+
+    # in app.pl
+    # ...
+    set engines => {
+        template_toolkit => {
+            embedded_templates => 1,
+        },
+    };
+    set template => 'template_toolkit';
+
+This feature requires L<Template::Provider::FromDATA>. Put your templates in the
+__DATA__ section, and start every template with __${templatename}__.
+
 =head1 SEE ALSO
 
 L<Dancer>, L<Template>
